#
# spec file for package python-barbicanclient
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-barbicanclient
Version:        5.2.0
Release:        1.3
Summary:        Client for the Barbican Key Management API
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://docs.openstack.org/python-barbicanclient
Source0:        https://files.pythonhosted.org/packages/source/p/python-barbicanclient/python-barbicanclient-5.2.0.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python3-cliff >= 2.8.0
BuildRequires:  python3-keystoneauth1 >= 3.4.0
BuildRequires:  python3-oslo.i18n >= 3.15.3
BuildRequires:  python3-oslo.serialization >= 2.18.0
BuildRequires:  python3-oslo.utils >= 3.33.0
BuildRequires:  python3-pbr >= 2.0.0
BuildRequires:  python3-requests >= 2.14.2
BuildRequires:  python3-requests-mock
BuildRequires:  python3-stestr
BuildRequires:  python3-testscenarios
BuildRequires:  python3-testtools
BuildArch:      noarch
%if 0%{?suse_version}
Requires(post): update-alternatives
Requires(postun):update-alternatives
%else
# on RDO, update-alternatives is in chkconfig
Requires(post): chkconfig
Requires(postun):chkconfig
%endif

%description
This is a client for the Barbican Key Management API. This package includes a
Python library for accessing the API (the barbicanclient module), and a
command-line script (barbican).

%package -n python3-barbicanclient
Summary:        Client for the Barbican Key Management API
Requires:       python3-cliff >= 2.8.0
Requires:       python3-keystoneauth1 >= 3.4.0
Requires:       python3-oslo.i18n >= 3.15.3
Requires:       python3-oslo.serialization >= 2.18.0
Requires:       python3-oslo.utils >= 3.33.0
Requires:       python3-pbr >= 2.0.0
Requires:       python3-requests >= 2.14.2
Requires:       python3-six
%if 0%{?suse_version}
Obsoletes:      python2-barbicanclient < 4.10.0
%endif

%description -n python3-barbicanclient
This is a client for the Barbican Key Management API. This package includes a
Python library for accessing the API (the barbicanclient module), and a
command-line script (barbican).

This package contains the Python 3.x module.

%package -n python-barbicanclient-doc
Summary:        Documentation for OpenStack Key Management API Client
Group:          Documentation/HTML
BuildRequires:  python3-Sphinx
BuildRequires:  python3-openstackdocstheme
BuildRequires:  python3-sphinxcontrib-svg2pdfconverter

%description -n python-barbicanclient-doc
Documentation for the client library for interacting with
Openstack Key Management API

%prep
%autosetup -p1 -n %{name}-%{version}
%py_req_cleanup

%build
%{py3_build}

# generate html docs
PBR_VERSION=%{version} %sphinx_build -b html doc/source doc/build/html
# Remove the sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}

%install
%{py3_install}

%check
python3 -m stestr.cli run \
    --black-regex 'barbicanclient.tests.test_barbican.WhenTestingBarbicanCLI.test_should_show_usage_with_help_flag'

%files -n python3-barbicanclient
%license LICENSE
%{python3_sitelib}/python_barbicanclient-%{version}-py?.*.egg-info
%{python3_sitelib}/barbicanclient
%{_bindir}/barbican

%files -n python-barbicanclient-doc
%doc README.rst doc/build/html
%license LICENSE

%changelog
* Tue May 24 2022 Dirk Müller <dmueller@suse.com>
- fix build against python 3.10
- remove unneeded mock dependency
* Tue Oct 26 2021 cloud-devel@suse.de
- update to version 5.2.0
* Sun May  2 2021 cloud-devel@suse.de
- update to version 5.1.0
  - [goal] Migrate tox based testing to ubuntu focal
  - bump py37 to py38 in tox.ini
  - Add Python3 wallaby unit tests
* Fri Oct  9 2020 cloud-devel@suse.de
- update to version 5.0.1
  - Use unittest.mock instead of third party mock
  - Switch to newer openstackdocstheme and reno versions
  - Switch from unittest2 compat methods to Python 3.x methods
  - Fix gate job failures and py3 compatibility
  - Zuul: port to native v3 job and add victoria unit tests
  - [ussuri][goal] Drop python 2.7 support and testing
  - Update hacking for Python3
  - add py38 package metadata
* Tue May 12 2020 cloud-devel@suse.de
- update to version 4.10.0
  - Bump the openstackdocstheme extension to 1.20
  - Support two-way auth for barbicanclient
  - PDF Documentation Build tox target
  - Fix lower-constraints tox target
  - docs: Turn on warning-as-error
* Mon Mar 23 2020 Dirk Mueller <dmueller@suse.com>
- add obsoletes
* Wed Mar 11 2020 Dirk Mueller <dmueller@suse.com>
- switch to python 3.x only build
* Wed Oct  9 2019 cloud-devel@suse.de
- update to version 4.9.0
  - Replace openstack.org git:// URLs with https://
  - Update json module to jsonutils
  - OpenDev Migration Patch
  - add python 3.7 unit test job
* Mon Apr  8 2019 cloud-devel@suse.de
- update to version 4.8.1
  - Update mailinglist from dev to discuss
  - Add Python 3.6 classifier to setup.cfg
  - Allow fetching by UUID, and respect interface
  - Change openstack-dev to openstack-discuss
  - Secret payload should also be fetched by UUID
  - Update hacking version
  - Import python-barbicanclient-dsvm
  - Update min tox version to 2.0
  - Don't quote {posargs} in tox.ini
  - switch documentation job to new PTI
  - add python 3.6 unit test job
  - Use template for lower-constraints
  - import zuul job settings from project-config
* Wed Feb  6 2019 cloud-devel@suse.de
- update to version 4.7.2
  - Secret payload should also be fetched by UUID
* Thu Dec  6 2018 cloud-devel@suse.de
- update to version 4.7.1
  - Update UPPER_CONSTRAINTS_FILE for stable/rocky
  - Import python-barbicanclient-dsvm
  - Allow fetching by UUID, and respect interface
  - Update .gitreview for stable/rocky
  - import zuul job settings from project-config
* Mon Sep  3 2018 cloud-devel@suse.de
- update to version 4.7.0
  - Add --file flag for secrets
  - fix tox python3 overrides
  - Remove PyPI downloads
  - use open() instead of file()
  - pypy is not checked at gate
  - Trivial: Update pypi url to new url
  - Update doc to use the correct order method
  - Supress client debug messages
  - Update the bugs link address
  - Updating time for functional tests
  - Follow the new PTI for document build
  - Update the old http links in docs
  - Add 'rm -f .testrepository/times.dbm' command in testenv
  - Updated from global requirements
  - add lower-constraints job
  - Switch to stestr
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
* Mon Feb 12 2018 cloud-devel@suse.de
- update to version 4.6.0 (bsc#1078607)
  - Switch to use new barbican endpoint
  - Correct docs usage of keystoneauth1 session
  - Fix some reST field lists in docstrings
  - Pass OSC interface through to barbican plugin
  - Avoid tox_install.sh for constraints support
  - Updated from global requirements
* Tue Jan 16 2018 dmueller@suse.com
- convert to singlespec
* Fri Sep 22 2017 cloud-devel@suse.de
- update to version 4.5.2
  - Refactor barbicanclient
  - Update doc references
  - rearrange the existing docs into the new standard layout
  - import content from cli-reference in openstack-manuals
  - Update the documentation link for doc migration
  - Workaround for importing objects from old path
  - Add secret_type filter to CLI
  - fix default version
  - Update api references according to refactor result
  - Support import modules from barbicanclient.client module
  - Updated from global requirements
  - Switch from oslosphinx to openstackdocstheme
* Mon Aug  7 2017 cloud-devel@suse.de
- update to version 4.4.0
  - Replace six.iteritems() with .items()
  - Removes unnecessary utf-8 encoding
  - Clean up all secrets in functional tests
  - Fix gate failure on pep8
  - Change parent class of `WhenTestingCertificateOrders`
  - Use generic auth plugin instead of specific version
  - Update .gitignore
  - Fix doc referencing --payload-content-type
  - Add client list filter functionality
  - Correct the regex for parsing output
  - Make test directory more specific
  - Extend pep8 test coverage
  - Set client module __version__
  - Remove support for py34
  - Fix serializable issues when retrieving json format resources
  - Replaces uuid.uuid4 with uuidutils.generate_uuid()
  - Enable F and H flake8 rules
  - Update keystone endpoint for functional tests
  - Remove unused barbicanclient/common directory
  - Updated from global requirements
  - [openstack-manuals] description of command barbican ca list
* Mon Feb 13 2017 cloud-devel@suse.de
- update to version 4.2.0:
  - Update Order Create Type Help Dialog
  - Remove redundant space in docstring
  - Replaced bare except
  - Fix order of arguments in assertEqual
  - Removed openstack/common from tox.in
  - Using assertEqual instead of assertEquals
  - Validate key order meta fields.
  - Fix bug when uploading secret using unified CLI
  - Remove discover from test-requirements
  - Use 'code-block' for pieces of code
  - Accept 'pass_phrase' for AsymmetricOrder constructor
  - Support upper-constraints in tox.ini
  - Skip order with 'None' payload content type
  - Add missing param to certificate order initialization
  - Fix argument order for assertEqual to (expected, observed)
  - Fix error in doc
  - Add Python 3.5 classifier and venv
  - Use international logging message
  - Using assertTrue/False() instead of assertEqual(True/False)
  - Use keystoneauth
  - Remove imported but unused
  - Fix CLI message in CA module
  - Add plug-in summary for osc doc
  - Cast sets to lists in acl functional tests
  - Handle container list command correctly
  - Add oslo.config to requirements
  - Do not write except:, use except Exception instead
  - Updated from global requirements
  - Remove invalid smoke test that is failing in the gate
* Fri Sep  2 2016 tbechtold@suse.com
  update to version 4.1.0
  * Updated from global requirements
  * Fix jenkins failing on coverage report
  * Fixed python-barbicanclient functional tests
  * Remove unused import
  * Update mailmap for Douglas Mendizábal
  * Update the home-page with developer documentation link
  * Issue deprecation message for the barbican CLI
  * Censoring secrets payload value from debug log
  * Fix argument order for assertEqual to (exp, obs)
  * Fixed barbican client order list
  * Display error description
* Mon Aug  1 2016 tbechtold@suse.com
- Update _service and switch to upstream spec file
* Thu May 26 2016 johannes.grassler@suse.com
- Update to 4.0.1
  4.0.1
  * Updated from global requirements
  * Update .gitreview for stable/mitaka
  4.0.0
  * Replace assertEqual(None, *
  * Updated from global requirements
  * Use six.moves.urllib.parse to replace urlparse
  * Updated from global requirements
  * Remove argparse from requirements
  * Updated from global requirements
  * Updated from global requirements
  * Replace deprecated keystoneclient...exceptions
  * Update typos
  * Removes MANIFEST.in as it is not needed explicitely by PBR
  * Deprecated tox -downloadcache option removed
  * Remove py26 support
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Update Readme to include new/updated CLI commands
  * Allow tox to be able to run independent functional tests
  * Make CLI Order's type field a required argument
  * Remove invalid skipping of tests
  * Fix Secrets Filter
  * Updated from global requirements
  * Updated from global requirements
  * README.rst devstack link not properly displayed
  * improve readme contents
  * Updated from global requirements
  * Add to_dict method to EntityFormatter
  * Updated from global requirements
  * Part 3: Adding ACL functional tests
  * Updated from global requirements
  * Initialize optional attributes in CA object
  * Fix keystone version selection
  * Part 2: Adding ACL support for CLI commands and docs
  * Fix incorrect error when performing Barbican Secret Update
  * Part 1: Adding ACL support for Client API
  * Fix error where barbican order create returns invalid error
  * Create Openstack CLI plugin for Barbican
  * Fix OS_PROJECT_ID not getting read by client
  * Remove Client V1 Behaviors
  * enable barbican help without authentication
  * Fix barbican-client README.rst
  * Add functional test for updating a Secret
  * Remove test behaviors abstraction for containers smoke tests
  * Remove test behaviors abstraction for orders smoke tests
  * Remove test behaviors abstraction for secrets smoke tests
  * Remove test behaviors abstraction for containers
  * Remove test behaviors abstraction for orders
  * Remove test behaviors abstraction for secrets
  * Create Common functions used for cleaning up items used for testing
  * Add epilog to parser
  * Add Unit Tests for Store and Update Payload when Payload is zero
  * Allow Barbican Client Secret Update Functionality
* Wed Sep 16 2015 tbechtold@suse.com
- update to 3.3.0:
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Add ability to add and list CAs
  * Remove unneeded dependency in tox.ini
  * Adding Documentation for running Functional Tests on the Python-Barbican Client
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Added secret type command line option
  * Updated from global requirements
  * New mock release(1.1.0) broke unit/function tests
  * Enable endpoint filter parameters for the CLI
  * Updated from global requirements
  * Use keystone discovery instead of endpoint_override
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Drop incubating theme from docs
  * Remove tempest config dependency in functional tests
  * Add capability of specifying Barbican version to client
  * Remove instances of _base_url
  * Re-merge CLI test update for auth URL and version
  * Add CLI smoke functional tests for containers
  * Create behaviors for secrets
  * Pass in keystone version and correct v2 URL to CLI
  * Add support for certificate order
  * Updated from global requirements
  * Adding new tests to cover failure scenarios
  * Drop use of 'oslo' namespace package
  * Updated from global requirements
  * Add Secret CLI smoke tests
  * Fix bug in CLI authentication
  * Updated from global requirements
  * Refactored barbican.py for better testability
  * Update stdout and stderr capture in functional tests
  * Use keystoneclient to get endpoint if it's empty
  * Initial setup for command line tests
  * Fixing misspelling in client docstring
  * Adding support for token based authentication
  * Cleaning up validate_ref()
  * Update README to work with release tools
  * Cleaning up Keystone auth tests
  * Excluding tests from coverage report
  * Fix the clientrc file to match defaults and add docs
  * Updating client and client docs for accuracy
  * Porting over more documentation to RST from cli wiki
  * Uncap library requirements for liberty
  * Adding payload flag to get secret
  * Raising errors from the client instead of ksclient
  * Fix order listing on the command line
  * Fixing the broken functional tests
  * Use the ksc Adapter instead of custom HTTPClient
- Adjust Requires according to requirements.txt
* Thu Apr 23 2015 tbechtold@suse.com
- Switch to version 3.0.3
* Tue Apr 21 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.1.0.post1:
  * Update README to work with release tools
  3.1.0
  * Excluding tests from coverage report
  * Uncap library requirements for liberty
* Sat Apr 18 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.3.post13:
  * Raising errors from the client instead of ksclient
* Fri Apr 17 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.3.post11:
  * Fix the clientrc file to match defaults and add docs
  * Updating client and client docs for accuracy
  * Porting over more documentation to RST from cli wiki
* Fri Apr 17 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.3.post7:
  * Adding payload flag to get secret
* Mon Apr 13 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.3.post6:
  * Use the ksc Adapter instead of custom HTTPClient
* Sun Apr 12 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.3.post4:
  * Fix order listing on the command line
* Fri Apr 10 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.3.post3:
  * Fixing the broken functional tests
* Wed Apr  1 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.3.post2:
  3.0.3
  * Negative tests for orders
* Tue Mar 31 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.2.post85:
  * Fix --decrypt command line option
  * Fix order creation on the command line
  * Don't ignore payload_content_encoding if set
* Sat Mar 28 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.2.post80:
  * Consolidate Payload Exceptions
* Wed Mar 25 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.2.post78:
  * Container negative tests
  * Second set of negative secrets tests
* Tue Mar 24 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.2.post74:
  * Updated from global requirements
  * First set of negative functional test for secrets
* Thu Mar 19 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.2.post71:
  * Fix smoke test for client with bad data set
  * Fixed deprecated type and encoding test and encoding bug
  * Removing assertItemsEqual workaround, fixed upstream
* Thu Mar 19 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.2.post67:
  * Fixes tests on invalid payload secret creation and adds new exception
* Wed Mar 18 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.2.post66:
  * Ensuring secret ref is not none with payload
  * Added new exception, renamed test, and adjusted test
  * Fixed max payload size error
  * Fix secret-store empty-key filtering bug
* Mon Mar 16 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.2.post60:
  * Enable usage of 'payload' path to fetch decrypted secrets
* Sun Mar 15 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.2.post58:
  * Don't use tempest log
* Sat Mar 14 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.2.post56:
  * Deprecate setting the payload type and encoding
  * Use functional_test.conf for devstack gate
* Thu Mar 12 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.2.post52:
  * Fix when submitting with empty string, none and zero
* Wed Mar 11 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.2.post50:
  * Fix delete a secret that does not exist
  * Do not filter empty strings
* Tue Mar 10 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.2.post46:
  * Pass correct api object to Container constructor
* Sun Mar  8 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.2.post44:
  * Refactor test modules
* Sat Mar  7 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.2.post42:
  * Moved parameterized test from smoke to functional
* Fri Mar  6 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.2.post40:
  * Add default max payload to functional test conf registry
  * Adds positive orders functional tests
  * Additional requests-mock testing
* Thu Mar  5 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.2.post34:
  * Remove cyclical dependency
  * Convert CRUD tests to requests-mock
* Wed Mar  4 2015 cloud-devel@suse.de
- Update to version python-barbicanclient-3.0.2.post30:
  * Updated functional tests to use both identity v2 and v3
  * Add secret_type to Secret constructor
* Mon Mar  2 2015 tbechtold@suse.com
- Update Requires
- Add -test package
* Mon Mar  2 2015 tbechtold@suse.com
- Initial version
